Error

Enum Error 

pub enum Error {
    Io(Error),
    Protocol(String),
    Auth(String),
    Database(DatabaseError),
    Conversion(String),
    Pool(String),
    Timeout,
    Closed,
    Unsupported(String),
}
O tipo de erro de nível mais alto.

Variants



Io(Error)

Falha de I/O no nível de transporte.



Protocol(String)

O par enviou algo que viola o protocolo de comunicação (wire protocol).



Auth(String)

Falha de autenticação/handshake (SRP, wire crypt, incompatibilidade de plugin).



Database(DatabaseError)

Um erro reportado pelo servidor com um status vector completo.



Conversion(String)

Um valor não pôde ser convertido de/para o tipo Rust solicitado.



Pool(String)

Falha no pool de conexões (esgotado, fechado, …).



Timeout

Uma operação excedeu seu prazo.



Closed

A conexão foi fechada e não pode mais ser usada.



Unsupported(String)

Um recurso ainda não é suportado pelo protocolo negociado ou por este driver.

Implementations

Source

impl Error

pub fn protocol(msg: impl Into<String>) -> Self

Cria um erro de protocolo para validações internas do driver.

pub fn auth(msg: impl Into<String>) -> Self

Cria um erro de autenticação ou negociação de criptografia.

pub fn conversion(msg: impl Into<String>) -> Self

Cria um erro de conversão de valor.

pub fn unsupported(msg: impl Into<String>) -> Self

Cria um erro para recurso ainda não suportado.

pub fn gds_code(&self) -> Option<i32>

Se este for um erro de banco de dados, o código de erro primário do Firebird (GDS).

pub fn sql_state(&self) -> Option<&str>

Se este for um erro de banco de dados, seu SQLSTATE (5 caracteres), quando fornecido.